diff --git a/agents/bootstrapper/pom.xml b/agents/bootstrapper/pom.xml
index 78a490fe7c..6ae1147a27 100644
--- a/agents/bootstrapper/pom.xml
+++ b/agents/bootstrapper/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTbootstrapperAgents :: Bootstrapper
diff --git a/agents/exec/pom.xml b/agents/exec/pom.xml
index 629b510274..8ecc872992 100644
--- a/agents/exec/pom.xml
+++ b/agents/exec/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTexec-agentAgent :: Exec
diff --git a/agents/git-credentials/pom.xml b/agents/git-credentials/pom.xml
index 77489e16cc..1b30f11c3e 100644
--- a/agents/git-credentials/pom.xml
+++ b/agents/git-credentials/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTgit-credentials-agentGit Credentials Agent
diff --git a/agents/go-agents/pom.xml b/agents/go-agents/pom.xml
index 5c8a7831f3..1cf09d4903 100644
--- a/agents/go-agents/pom.xml
+++ b/agents/go-agents/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTgo-agentsAgent :: Golang agents
diff --git a/agents/ls-csharp/pom.xml b/agents/ls-csharp/pom.xml
index de2a15ce2e..5d3261ea8b 100644
--- a/agents/ls-csharp/pom.xml
+++ b/agents/ls-csharp/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTls-csharp-agentLanguage Server C# Agent
diff --git a/agents/ls-json/pom.xml b/agents/ls-json/pom.xml
index 7e166c4c63..5511faa83c 100644
--- a/agents/ls-json/pom.xml
+++ b/agents/ls-json/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTls-json-agentLanguage Server Json Agent
diff --git a/agents/ls-php/pom.xml b/agents/ls-php/pom.xml
index ec4a519525..19247b386b 100644
--- a/agents/ls-php/pom.xml
+++ b/agents/ls-php/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTls-php-agentLanguage Server PHP Agent
diff --git a/agents/ls-python/pom.xml b/agents/ls-python/pom.xml
index 3c9be86bd4..72e4ad4952 100644
--- a/agents/ls-python/pom.xml
+++ b/agents/ls-python/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTls-python-agentLanguage Server python Agent
diff --git a/agents/ls-typescript/pom.xml b/agents/ls-typescript/pom.xml
index 73e215e039..bf9117b500 100644
--- a/agents/ls-typescript/pom.xml
+++ b/agents/ls-typescript/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTls-typescript-agentLanguage Server typescript Agent
diff --git a/agents/pom.xml b/agents/pom.xml
index 6f76088402..b15f6496aa 100644
--- a/agents/pom.xml
+++ b/agents/pom.xml
@@ -16,11 +16,11 @@
che-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOT../pom.xmlche-agents-parent
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTpomChe Agents Parent
diff --git a/agents/ssh/pom.xml b/agents/ssh/pom.xml
index 3f903e2ba9..38cbcfc498 100644
--- a/agents/ssh/pom.xml
+++ b/agents/ssh/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTssh-agentSSH Agent
diff --git a/agents/terminal/pom.xml b/agents/terminal/pom.xml
index 5ae89b31ce..0ae2de7242 100644
--- a/agents/terminal/pom.xml
+++ b/agents/terminal/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTterminal-agentAgent :: Terminal
diff --git a/agents/unison/pom.xml b/agents/unison/pom.xml
index 9c6749c948..efb48295ad 100644
--- a/agents/unison/pom.xml
+++ b/agents/unison/pom.xml
@@ -16,7 +16,7 @@
che-agents-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTunison-agentUnison Agent
diff --git a/assembly/assembly-ide-war/pom.xml b/assembly/assembly-ide-war/pom.xml
index 0763c489bb..8adf131cbc 100644
--- a/assembly/assembly-ide-war/pom.xml
+++ b/assembly/assembly-ide-war/pom.xml
@@ -16,7 +16,7 @@
che-assembly-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTassembly-ide-warwar
@@ -31,6 +31,10 @@
org.eclipse.che.coreche-ide-core
+
+ org.eclipse.che.plugin
+ che-plugin-activity-ide
+ org.eclipse.che.pluginche-plugin-composer-ide
@@ -413,9 +417,25 @@
${generated.sources.directory}
+ src/main/java
+
+ add-resource
+ generate-resources
+
+ add-resource
+
+
+
+
+ src/main/webapp
+
+
+
+
+
diff --git a/assembly/assembly-main/pom.xml b/assembly/assembly-main/pom.xml
index 002d4859e4..0f40990ca8 100644
--- a/assembly/assembly-main/pom.xml
+++ b/assembly/assembly-main/pom.xml
@@ -16,7 +16,7 @@
che-assembly-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTassembly-mainpom
diff --git a/assembly/assembly-wsagent-server/pom.xml b/assembly/assembly-wsagent-server/pom.xml
index f18d602b0d..f5ad7acd22 100644
--- a/assembly/assembly-wsagent-server/pom.xml
+++ b/assembly/assembly-wsagent-server/pom.xml
@@ -16,7 +16,7 @@
che-assembly-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTassembly-wsagent-serverpom
diff --git a/assembly/assembly-wsagent-war/overlays/org.eclipse.che.core.che-wsagent-core-5.16.0-SNAPSHOT.info b/assembly/assembly-wsagent-war/overlays/org.eclipse.che.core.che-wsagent-core-5.16.0-SNAPSHOT.info
new file mode 100644
index 0000000000..b47fa74f47
--- /dev/null
+++ b/assembly/assembly-wsagent-war/overlays/org.eclipse.che.core.che-wsagent-core-5.16.0-SNAPSHOT.info
@@ -0,0 +1,3 @@
+1502958214000
+(?:[^/]+/)*?[^/]*?
+META-INF(?:$|/.+)
\ No newline at end of file
diff --git a/assembly/assembly-wsagent-war/pom.xml b/assembly/assembly-wsagent-war/pom.xml
index c5c4a2ce9d..316f098f5e 100644
--- a/assembly/assembly-wsagent-war/pom.xml
+++ b/assembly/assembly-wsagent-war/pom.xml
@@ -16,7 +16,7 @@
che-assembly-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTassembly-wsagent-warwar
@@ -31,6 +31,10 @@
org.eclipse.che.libche-swagger-module
+
+ org.eclipse.che.plugin
+ che-plugin-activity-server
+ org.eclipse.che.pluginche-plugin-composer-server
diff --git a/assembly/assembly-wsmaster-war/pom.xml b/assembly/assembly-wsmaster-war/pom.xml
index a76a266832..50bbfd7a8a 100644
--- a/assembly/assembly-wsmaster-war/pom.xml
+++ b/assembly/assembly-wsmaster-war/pom.xml
@@ -16,7 +16,7 @@
che-assembly-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTassembly-wsmaster-warwar
@@ -196,6 +196,10 @@
org.eclipse.che.libche-swagger-module
+
+ org.eclipse.che.plugin
+ che-plugin-activity-wsmaster
+ org.eclipse.che.pluginche-plugin-docker-client
diff --git a/assembly/assembly-wsmaster-war/src/main/java/org/eclipse/che/api/deploy/WsMasterModule.java b/assembly/assembly-wsmaster-war/src/main/java/org/eclipse/che/api/deploy/WsMasterModule.java
index 7f5a152ed3..8cff552bf7 100644
--- a/assembly/assembly-wsmaster-war/src/main/java/org/eclipse/che/api/deploy/WsMasterModule.java
+++ b/assembly/assembly-wsmaster-war/src/main/java/org/eclipse/che/api/deploy/WsMasterModule.java
@@ -165,7 +165,7 @@ public class WsMasterModule extends AbstractModule {
bind(org.eclipse.che.api.deploy.WsMasterAnalyticsAddresser.class);
- install(new org.eclipse.che.api.workspace.server.activity.inject.WorkspaceActivityModule());
+ install(new org.eclipse.che.plugin.activity.inject.WorkspaceActivityModule());
install(new org.eclipse.che.api.core.rest.CoreRestModule());
install(new org.eclipse.che.api.core.util.FileCleaner.FileCleanerModule());
diff --git a/assembly/pom.xml b/assembly/pom.xml
index f22644cc7a..b29cc42f50 100644
--- a/assembly/pom.xml
+++ b/assembly/pom.xml
@@ -16,12 +16,12 @@
che-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOT../pom.xmlorg.eclipse.cheche-assembly-parent
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTpomChe IDE :: Parent
diff --git a/core/che-core-api-core/pom.xml b/core/che-core-api-core/pom.xml
index fcf33d6e6b..cd0749b704 100644
--- a/core/che-core-api-core/pom.xml
+++ b/core/che-core-api-core/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-api-corejar
diff --git a/core/che-core-api-dto-maven-plugin/pom.xml b/core/che-core-api-dto-maven-plugin/pom.xml
index 50408b6b52..9a2f8ef177 100644
--- a/core/che-core-api-dto-maven-plugin/pom.xml
+++ b/core/che-core-api-dto-maven-plugin/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-api-dto-maven-pluginmaven-plugin
diff --git a/core/che-core-api-dto/pom.xml b/core/che-core-api-dto/pom.xml
index 51df3d27d2..edb08a0d06 100644
--- a/core/che-core-api-dto/pom.xml
+++ b/core/che-core-api-dto/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-api-dtojar
diff --git a/core/che-core-api-model/pom.xml b/core/che-core-api-model/pom.xml
index 3a3fd91b48..638028d60d 100644
--- a/core/che-core-api-model/pom.xml
+++ b/core/che-core-api-model/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-api-modeljar
diff --git a/core/che-core-db-vendor-h2/pom.xml b/core/che-core-db-vendor-h2/pom.xml
index bdebb9f4af..ba4b5f94f2 100644
--- a/core/che-core-db-vendor-h2/pom.xml
+++ b/core/che-core-db-vendor-h2/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-db-vendor-h2Che Core :: DB :: Vendor H2
diff --git a/core/che-core-db-vendor-postgresql/pom.xml b/core/che-core-db-vendor-postgresql/pom.xml
index 4d81599c19..a310103376 100644
--- a/core/che-core-db-vendor-postgresql/pom.xml
+++ b/core/che-core-db-vendor-postgresql/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-db-vendor-postgresqlChe Core :: DB :: Vendor PostgreSQL
diff --git a/core/che-core-db/pom.xml b/core/che-core-db/pom.xml
index ef20b5ce3e..599d480ef1 100644
--- a/core/che-core-db/pom.xml
+++ b/core/che-core-db/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-dbChe Core :: DB
diff --git a/core/che-core-typescript-dto-maven-plugin/pom.xml b/core/che-core-typescript-dto-maven-plugin/pom.xml
index 8a92a7de77..2d0a91c4c2 100644
--- a/core/che-core-typescript-dto-maven-plugin/pom.xml
+++ b/core/che-core-typescript-dto-maven-plugin/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTorg.eclipse.che.coreche-core-typescript-dto-maven-plugin
diff --git a/core/commons/che-core-commons-annotations/pom.xml b/core/commons/che-core-commons-annotations/pom.xml
index 9da0bc0064..d3bdec8ef5 100644
--- a/core/commons/che-core-commons-annotations/pom.xml
+++ b/core/commons/che-core-commons-annotations/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-annotationsjar
diff --git a/core/commons/che-core-commons-inject/pom.xml b/core/commons/che-core-commons-inject/pom.xml
index c6b563b0bc..7d914043ff 100644
--- a/core/commons/che-core-commons-inject/pom.xml
+++ b/core/commons/che-core-commons-inject/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-injectjar
diff --git a/core/commons/che-core-commons-j2ee/pom.xml b/core/commons/che-core-commons-j2ee/pom.xml
index a4e7974d99..7f8b68003d 100644
--- a/core/commons/che-core-commons-j2ee/pom.xml
+++ b/core/commons/che-core-commons-j2ee/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-j2eejar
diff --git a/core/commons/che-core-commons-json/pom.xml b/core/commons/che-core-commons-json/pom.xml
index 45c3b92b9b..d176457053 100644
--- a/core/commons/che-core-commons-json/pom.xml
+++ b/core/commons/che-core-commons-json/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-jsonjar
diff --git a/core/commons/che-core-commons-lang/pom.xml b/core/commons/che-core-commons-lang/pom.xml
index 60328e61f2..89cbac4cb6 100644
--- a/core/commons/che-core-commons-lang/pom.xml
+++ b/core/commons/che-core-commons-lang/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-langjar
diff --git a/core/commons/che-core-commons-schedule/pom.xml b/core/commons/che-core-commons-schedule/pom.xml
index 46e4d2483c..0cb9b45102 100644
--- a/core/commons/che-core-commons-schedule/pom.xml
+++ b/core/commons/che-core-commons-schedule/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-schedulejar
diff --git a/core/commons/che-core-commons-test/pom.xml b/core/commons/che-core-commons-test/pom.xml
index 82b69bdcd9..b643e7ca80 100644
--- a/core/commons/che-core-commons-test/pom.xml
+++ b/core/commons/che-core-commons-test/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-testjar
diff --git a/core/commons/che-core-commons-xml/pom.xml b/core/commons/che-core-commons-xml/pom.xml
index 30bfc2fcb0..e3f6f7193c 100644
--- a/core/commons/che-core-commons-xml/pom.xml
+++ b/core/commons/che-core-commons-xml/pom.xml
@@ -16,7 +16,7 @@
che-core-commons-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-commons-xmljar
diff --git a/core/commons/pom.xml b/core/commons/pom.xml
index cd252d61fb..782d4fcaad 100644
--- a/core/commons/pom.xml
+++ b/core/commons/pom.xml
@@ -16,7 +16,7 @@
che-core-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOT../pom.xmlche-core-commons-parent
diff --git a/core/pom.xml b/core/pom.xml
index e363f0e801..332811c92e 100644
--- a/core/pom.xml
+++ b/core/pom.xml
@@ -16,12 +16,12 @@
che-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOT../pom.xmlorg.eclipse.che.coreche-core-parent
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTpomChe Core Parent
diff --git a/dashboard/.dockerignore b/dashboard/.dockerignore
new file mode 100644
index 0000000000..c7a029b0d8
--- /dev/null
+++ b/dashboard/.dockerignore
@@ -0,0 +1,27 @@
+Dockerfile
+node_modules
+bower_components
+target
+pom.xml
+./typings
+./tmp
+./codeverage
+
+# Eclipse #
+###################
+
+*.launch
+.classpath
+.project
+.settings/
+bin/
+test-output/
+maven-eclipse.xml
+
+# Idea #
+##################
+*.iml
+*.ipr
+*.iws
+.idea/
+
diff --git a/dashboard/Dockerfile b/dashboard/Dockerfile
new file mode 100644
index 0000000000..97f8543a76
--- /dev/null
+++ b/dashboard/Dockerfile
@@ -0,0 +1,22 @@
+# Copyright (c) 2012-2017 Red Hat, Inc
+# All rights reserved. This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v1.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v10.html
+
+# This is a Dockerfile allowing to build dashboard by using a docker container.
+# Build step: $ docker build -t eclipse-che-dashboard
+# It builds an archive file that can be used by doing later
+# $ docker run --rm eclipse-che-dashboard | tar -C target/ -zxf -
+FROM mhart/alpine-node:6
+
+RUN apk update && \
+ apk add --no-cache git
+COPY package.json /dashboard/
+RUN cd /dashboard && npm install
+COPY bower.json /dashboard/
+RUN cd /dashboard && ./node_modules/.bin/bower install --allow-root
+COPY . /dashboard/
+RUN cd /dashboard && npm run build && cd target/ && tar zcf /tmp/dashboard.tar.gz dist/
+
+CMD zcat /tmp/dashboard.tar.gz
diff --git a/dashboard/README.md b/dashboard/README.md
index f0d0552104..bc0c9c7dea 100644
--- a/dashboard/README.md
+++ b/dashboard/README.md
@@ -4,20 +4,30 @@ Eclipse Che is a next generation Eclipse IDE and open source alternative to Inte
Che Dashboard
==============
-#Requirements
-- Python `v2.7.x`(`v3.x.x`currently not supported)
-- Node.js `v4.x.x` (`v5.x.x` / `v6.x.x` are currently not supported)
-- npm
+## Requirements
+- Docker
-Installation instructions for Node.js and npm can be found on the following [link](https://docs.npmjs.com/getting-started/installing-node).
-
-#Quick start
+## Quick start
```sh
cd che/dashboard
mvn clean install
```
+note: by default it will build dashboard using a docker image.
+If all required tools are installed locally, the native profile can be used instead of the docker build by following command:
+
+```sh
+$ mvn -Pnative clean install
+```
+
+Required tools for native build:
+- Python `v2.7.x`(`v3.x.x`currently not supported)
+- Node.js `v4.x.x`, `v5.x.x` or `v6.x.x`
+- npm
+
+Installation instructions for Node.js and npm can be found on the following [link](https://docs.npmjs.com/getting-started/installing-node).
+
## Running
In order to run the project, the serve command is used
```sh
diff --git a/dashboard/gulp/conf.js b/dashboard/gulp/conf.js
index 8fed831363..fbeabe263a 100644
--- a/dashboard/gulp/conf.js
+++ b/dashboard/gulp/conf.js
@@ -16,7 +16,7 @@ var gutil = require('gulp-util');
*/
exports.paths = {
src: 'src',
- dist: 'dist',
+ dist: 'target/dist',
tmp: '.tmp',
e2e: 'e2e'
};
diff --git a/dashboard/pom.xml b/dashboard/pom.xml
index fd2ae48a84..6274df8a4c 100644
--- a/dashboard/pom.xml
+++ b/dashboard/pom.xml
@@ -16,12 +16,12 @@
che-parentorg.eclipse.che
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOT../pom.xmlorg.eclipse.che.dashboardche-dashboard-war
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTwarChe Dashboard :: Web App2015
@@ -35,72 +35,13 @@
dashboard-war
-
- maven-clean-plugin
-
-
-
- ${basedir}/bower_components
- false
-
-
- ${basedir}/node_modules
- false
-
-
- ${basedir}/dist
- false
-
-
-
-
-
- maven-antrun-plugin
-
-
- compile
- compile
-
- run
-
-
-
-
-
-
-
-
-
- ]]>
- ]]>
-
-
-
-
-
- compilation
- test
-
- run
-
-
-
-
-
-
-
-
-
-
-
- org.apache.maven.pluginsmaven-war-plugin
- dist
+ target/dist${basedir}/src/webapp/WEB-INF/web.xml
@@ -129,6 +70,134 @@
+
+
+ docker
+
+ true
+
+
+
+
+ maven-antrun-plugin
+
+
+ build-image
+ generate-sources
+
+ run
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ unpack-docker-build
+ generate-sources
+
+ run
+
+
+
+
+
+
+
+
+
+
+
+
+ update-href
+ prepare-package
+
+ run
+
+
+
+
+
+ ]]>
+ ]]>
+
+
+
+
+
+
+
+
+
+
+ native
+
+
+
+ maven-clean-plugin
+
+
+
+ ${basedir}/bower_components
+ false
+
+
+ ${basedir}/node_modules
+ false
+
+
+
+
+
+ maven-antrun-plugin
+
+
+ build-dashboard
+ compile
+
+ run
+
+
+
+
+
+
+
+
+
+ ]]>
+ ]]>
+
+
+
+
+
+ compilation
+ test
+
+ run
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ qa
diff --git a/dashboard/src/app/workspaces/list-workspaces/workspace-item/workspace-item.html b/dashboard/src/app/workspaces/list-workspaces/workspace-item/workspace-item.html
index da05f5dcc7..f7de49adcd 100644
--- a/dashboard/src/app/workspaces/list-workspaces/workspace-item/workspace-item.html
+++ b/dashboard/src/app/workspaces/list-workspaces/workspace-item/workspace-item.html
@@ -39,7 +39,7 @@
RAM{{workspaceItemCtrl.getMemoryLimit(workspaceItemCtrl.workspace)}}
diff --git a/dockerfiles/che/open-jdk-source-file-location b/dockerfiles/che/open-jdk-source-file-location
index 6030b59b83..8a72562661 100644
--- a/dockerfiles/che/open-jdk-source-file-location
+++ b/dockerfiles/che/open-jdk-source-file-location
@@ -10,3 +10,353 @@ The source code and build scripts used to create this binary are available for d
* grab official jdk sources by version from "http://hg.openjdk.java.net" reference - https://git.alpinelinux.org/cgit/aports/tree/community/openjdk8/APKBUILD?id=027d8ceca1422c0ffc3fe3a22523f22abedd694c#n43
* add alpine specific patches reference - https://git.alpinelinux.org/cgit/aports/tree/community/openjdk8?id=027d8ceca1422c0ffc3fe3a22523f22abedd694c
* perform build
+
+The following license applies to OpenJDK
+
+The GNU General Public License (GPL)
+
+Version 2, June 1991
+
+Copyright (C) 1989, 1991 Free Software Foundation, Inc.
+59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+
+Everyone is permitted to copy and distribute verbatim copies of this license
+document, but changing it is not allowed.
+
+Preamble
+
+The licenses for most software are designed to take away your freedom to share
+and change it. By contrast, the GNU General Public License is intended to
+guarantee your freedom to share and change free software--to make sure the
+software is free for all its users. This General Public License applies to
+most of the Free Software Foundation's software and to any other program whose
+authors commit to using it. (Some other Free Software Foundation software is
+covered by the GNU Library General Public License instead.) You can apply it to
+your programs, too.
+
+When we speak of free software, we are referring to freedom, not price. Our
+General Public Licenses are designed to make sure that you have the freedom to
+distribute copies of free software (and charge for this service if you wish),
+that you receive source code or can get it if you want it, that you can change
+the software or use pieces of it in new free programs; and that you know you
+can do these things.
+
+To protect your rights, we need to make restrictions that forbid anyone to deny
+you these rights or to ask you to surrender the rights. These restrictions
+translate to certain responsibilities for you if you distribute copies of the
+software, or if you modify it.
+
+For example, if you distribute copies of such a program, whether gratis or for
+a fee, you must give the recipients all the rights that you have. You must
+make sure that they, too, receive or can get the source code. And you must
+show them these terms so they know their rights.
+
+We protect your rights with two steps: (1) copyright the software, and (2)
+offer you this license which gives you legal permission to copy, distribute
+and/or modify the software.
+
+Also, for each author's protection and ours, we want to make certain that
+everyone understands that there is no warranty for this free software. If the
+software is modified by someone else and passed on, we want its recipients to
+know that what they have is not the original, so that any problems introduced
+by others will not reflect on the original authors' reputations.
+
+Finally, any free program is threatened constantly by software patents. We
+wish to avoid the danger that redistributors of a free program will
+individually obtain patent licenses, in effect making the program proprietary.
+To prevent this, we have made it clear that any patent must be licensed for
+everyone's free use or not licensed at all.
+
+The precise terms and conditions for copying, distribution and modification
+follow.
+
+TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
+
+0. This License applies to any program or other work which contains a notice
+placed by the copyright holder saying it may be distributed under the terms of
+this General Public License. The "Program", below, refers to any such program
+or work, and a "work based on the Program" means either the Program or any
+derivative work under copyright law: that is to say, a work containing the
+Program or a portion of it, either verbatim or with modifications and/or
+translated into another language. (Hereinafter, translation is included
+without limitation in the term "modification".) Each licensee is addressed as
+"you".
+
+Activities other than copying, distribution and modification are not covered by
+this License; they are outside its scope. The act of running the Program is
+not restricted, and the output from the Program is covered only if its contents
+constitute a work based on the Program (independent of having been made by
+running the Program). Whether that is true depends on what the Program does.
+
+1. You may copy and distribute verbatim copies of the Program's source code as
+you receive it, in any medium, provided that you conspicuously and
+appropriately publish on each copy an appropriate copyright notice and
+disclaimer of warranty; keep intact all the notices that refer to this License
+and to the absence of any warranty; and give any other recipients of the
+Program a copy of this License along with the Program.
+
+You may charge a fee for the physical act of transferring a copy, and you may
+at your option offer warranty protection in exchange for a fee.
+
+2. You may modify your copy or copies of the Program or any portion of it, thus
+forming a work based on the Program, and copy and distribute such modifications
+or work under the terms of Section 1 above, provided that you also meet all of
+these conditions:
+
+ a) You must cause the modified files to carry prominent notices stating
+ that you changed the files and the date of any change.
+
+ b) You must cause any work that you distribute or publish, that in whole or
+ in part contains or is derived from the Program or any part thereof, to be
+ licensed as a whole at no charge to all third parties under the terms of
+ this License.
+
+ c) If the modified program normally reads commands interactively when run,
+ you must cause it, when started running for such interactive use in the
+ most ordinary way, to print or display an announcement including an
+ appropriate copyright notice and a notice that there is no warranty (or
+ else, saying that you provide a warranty) and that users may redistribute
+ the program under these conditions, and telling the user how to view a copy
+ of this License. (Exception: if the Program itself is interactive but does
+ not normally print such an announcement, your work based on the Program is
+ not required to print an announcement.)
+
+These requirements apply to the modified work as a whole. If identifiable
+sections of that work are not derived from the Program, and can be reasonably
+considered independent and separate works in themselves, then this License, and
+its terms, do not apply to those sections when you distribute them as separate
+works. But when you distribute the same sections as part of a whole which is a
+work based on the Program, the distribution of the whole must be on the terms
+of this License, whose permissions for other licensees extend to the entire
+whole, and thus to each and every part regardless of who wrote it.
+
+Thus, it is not the intent of this section to claim rights or contest your
+rights to work written entirely by you; rather, the intent is to exercise the
+right to control the distribution of derivative or collective works based on
+the Program.
+
+In addition, mere aggregation of another work not based on the Program with the
+Program (or with a work based on the Program) on a volume of a storage or
+distribution medium does not bring the other work under the scope of this
+License.
+
+3. You may copy and distribute the Program (or a work based on it, under
+Section 2) in object code or executable form under the terms of Sections 1 and
+2 above provided that you also do one of the following:
+
+ a) Accompany it with the complete corresponding machine-readable source
+ code, which must be distributed under the terms of Sections 1 and 2 above
+ on a medium customarily used for software interchange; or,
+
+ b) Accompany it with a written offer, valid for at least three years, to
+ give any third party, for a charge no more than your cost of physically
+ performing source distribution, a complete machine-readable copy of the
+ corresponding source code, to be distributed under the terms of Sections 1
+ and 2 above on a medium customarily used for software interchange; or,
+
+ c) Accompany it with the information you received as to the offer to
+ distribute corresponding source code. (This alternative is allowed only
+ for noncommercial distribution and only if you received the program in
+ object code or executable form with such an offer, in accord with
+ Subsection b above.)
+
+The source code for a work means the preferred form of the work for making
+modifications to it. For an executable work, complete source code means all
+the source code for all modules it contains, plus any associated interface
+definition files, plus the scripts used to control compilation and installation
+of the executable. However, as a special exception, the source code
+distributed need not include anything that is normally distributed (in either
+source or binary form) with the major components (compiler, kernel, and so on)
+of the operating system on which the executable runs, unless that component
+itself accompanies the executable.
+
+If distribution of executable or object code is made by offering access to copy
+from a designated place, then offering equivalent access to copy the source
+code from the same place counts as distribution of the source code, even though
+third parties are not compelled to copy the source along with the object code.
+
+4. You may not copy, modify, sublicense, or distribute the Program except as
+expressly provided under this License. Any attempt otherwise to copy, modify,
+sublicense or distribute the Program is void, and will automatically terminate
+your rights under this License. However, parties who have received copies, or
+rights, from you under this License will not have their licenses terminated so
+long as such parties remain in full compliance.
+
+5. You are not required to accept this License, since you have not signed it.
+However, nothing else grants you permission to modify or distribute the Program
+or its derivative works. These actions are prohibited by law if you do not
+accept this License. Therefore, by modifying or distributing the Program (or
+any work based on the Program), you indicate your acceptance of this License to
+do so, and all its terms and conditions for copying, distributing or modifying
+the Program or works based on it.
+
+6. Each time you redistribute the Program (or any work based on the Program),
+the recipient automatically receives a license from the original licensor to
+copy, distribute or modify the Program subject to these terms and conditions.
+You may not impose any further restrictions on the recipients' exercise of the
+rights granted herein. You are not responsible for enforcing compliance by
+third parties to this License.
+
+7. If, as a consequence of a court judgment or allegation of patent
+infringement or for any other reason (not limited to patent issues), conditions
+are imposed on you (whether by court order, agreement or otherwise) that
+contradict the conditions of this License, they do not excuse you from the
+conditions of this License. If you cannot distribute so as to satisfy
+simultaneously your obligations under this License and any other pertinent
+obligations, then as a consequence you may not distribute the Program at all.
+For example, if a patent license would not permit royalty-free redistribution
+of the Program by all those who receive copies directly or indirectly through
+you, then the only way you could satisfy both it and this License would be to
+refrain entirely from distribution of the Program.
+
+If any portion of this section is held invalid or unenforceable under any
+particular circumstance, the balance of the section is intended to apply and
+the section as a whole is intended to apply in other circumstances.
+
+It is not the purpose of this section to induce you to infringe any patents or
+other property right claims or to contest validity of any such claims; this
+section has the sole purpose of protecting the integrity of the free software
+distribution system, which is implemented by public license practices. Many
+people have made generous contributions to the wide range of software
+distributed through that system in reliance on consistent application of that
+system; it is up to the author/donor to decide if he or she is willing to
+distribute software through any other system and a licensee cannot impose that
+choice.
+
+This section is intended to make thoroughly clear what is believed to be a
+consequence of the rest of this License.
+
+8. If the distribution and/or use of the Program is restricted in certain
+countries either by patents or by copyrighted interfaces, the original
+copyright holder who places the Program under this License may add an explicit
+geographical distribution limitation excluding those countries, so that
+distribution is permitted only in or among countries not thus excluded. In
+such case, this License incorporates the limitation as if written in the body
+of this License.
+
+9. The Free Software Foundation may publish revised and/or new versions of the
+General Public License from time to time. Such new versions will be similar in
+spirit to the present version, but may differ in detail to address new problems
+or concerns.
+
+Each version is given a distinguishing version number. If the Program
+specifies a version number of this License which applies to it and "any later
+version", you have the option of following the terms and conditions either of
+that version or of any later version published by the Free Software Foundation.
+If the Program does not specify a version number of this License, you may
+choose any version ever published by the Free Software Foundation.
+
+10. If you wish to incorporate parts of the Program into other free programs
+whose distribution conditions are different, write to the author to ask for
+permission. For software which is copyrighted by the Free Software Foundation,
+write to the Free Software Foundation; we sometimes make exceptions for this.
+Our decision will be guided by the two goals of preserving the free status of
+all derivatives of our free software and of promoting the sharing and reuse of
+software generally.
+
+NO WARRANTY
+
+11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY FOR
+THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN OTHERWISE
+STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES PROVIDE THE
+PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,
+INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
+FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK AS TO THE QUALITY AND
+PERFORMANCE OF THE PROGRAM IS WITH YOU. SHOULD THE PROGRAM PROVE DEFECTIVE,
+YOU ASSUME THE COST OF ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
+
+12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL
+ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE
+PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY
+GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR
+INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA
+BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER
+OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
+
+END OF TERMS AND CONDITIONS
+
+How to Apply These Terms to Your New Programs
+
+If you develop a new program, and you want it to be of the greatest possible
+use to the public, the best way to achieve this is to make it free software
+which everyone can redistribute and change under these terms.
+
+To do so, attach the following notices to the program. It is safest to attach
+them to the start of each source file to most effectively convey the exclusion
+of warranty; and each file should have at least the "copyright" line and a
+pointer to where the full notice is found.
+
+ One line to give the program's name and a brief idea of what it does.
+
+ Copyright (C)
+
+ This program is free software; you can redistribute it and/or modify it
+ under the terms of the GNU General Public License as published by the Free
+ Software Foundation; either version 2 of the License, or (at your option)
+ any later version.
+
+ This program is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ more details.
+
+ You should have received a copy of the GNU General Public License along
+ with this program; if not, write to the Free Software Foundation, Inc., 59
+ Temple Place, Suite 330, Boston, MA 02111-1307 USA
+
+Also add information on how to contact you by electronic and paper mail.
+
+If the program is interactive, make it output a short notice like this when it
+starts in an interactive mode:
+
+ Gnomovision version 69, Copyright (C) year name of author Gnomovision comes
+ with ABSOLUTELY NO WARRANTY; for details type 'show w'. This is free
+ software, and you are welcome to redistribute it under certain conditions;
+ type 'show c' for details.
+
+The hypothetical commands 'show w' and 'show c' should show the appropriate
+parts of the General Public License. Of course, the commands you use may be
+called something other than 'show w' and 'show c'; they could even be
+mouse-clicks or menu items--whatever suits your program.
+
+You should also get your employer (if you work as a programmer) or your school,
+if any, to sign a "copyright disclaimer" for the program, if necessary. Here
+is a sample; alter the names:
+
+ Yoyodyne, Inc., hereby disclaims all copyright interest in the program
+ 'Gnomovision' (which makes passes at compilers) written by James Hacker.
+
+ signature of Ty Coon, 1 April 1989
+
+ Ty Coon, President of Vice
+
+This General Public License does not permit incorporating your program into
+proprietary programs. If your program is a subroutine library, you may
+consider it more useful to permit linking proprietary applications with the
+library. If this is what you want to do, use the GNU Library General Public
+License instead of this License.
+
+
+"CLASSPATH" EXCEPTION TO THE GPL
+
+Certain source files distributed by Oracle America and/or its affiliates are
+subject to the following clarification and special exception to the GPL, but
+only where Oracle has expressly included in the particular source file's header
+the words "Oracle designates this particular file as subject to the "Classpath"
+exception as provided by Oracle in the LICENSE file that accompanied this code."
+
+ Linking this library statically or dynamically with other modules is making
+ a combined work based on this library. Thus, the terms and conditions of
+ the GNU General Public License cover the whole combination.
+
+ As a special exception, the copyright holders of this library give you
+ permission to link this library with independent modules to produce an
+ executable, regardless of the license terms of these independent modules,
+ and to copy and distribute the resulting executable under terms of your
+ choice, provided that you also meet, for each linked independent module,
+ the terms and conditions of the license of that module. An independent
+ module is a module which is not derived from or based on this library. If
+ you modify this library, you may extend this exception to your version of
+ the library, but you are not obligated to do so. If you do not wish to do
+ so, delete this exception statement from your version.
diff --git a/dockerfiles/cli/version/5.17.0/images b/dockerfiles/cli/version/5.17.0/images
new file mode 100644
index 0000000000..16a83e5baf
--- /dev/null
+++ b/dockerfiles/cli/version/5.17.0/images
@@ -0,0 +1,4 @@
+IMAGE_INIT=eclipse/che-init:5.17.0
+IMAGE_CHE=eclipse/che-server:5.17.0
+IMAGE_COMPOSE=docker/compose:1.8.1
+IMAGE_TRAEFIK=traefik:v1.3.0-rc3
diff --git a/dockerfiles/cli/version/5.17.0/images-stacks b/dockerfiles/cli/version/5.17.0/images-stacks
new file mode 100644
index 0000000000..4630f02af6
--- /dev/null
+++ b/dockerfiles/cli/version/5.17.0/images-stacks
@@ -0,0 +1,24 @@
+eclipse/alpine_jdk8
+eclipse/aspnet
+eclipse/centos_jdk8
+eclipse/cpp_gcc
+eclipse/debian_jdk8
+eclipse/debian_jdk8_node
+eclipse/debian_jre
+eclipse/dotnet_core
+eclipse/hadoop-dev
+eclipse/meteor
+eclipse/node
+eclipse/php
+eclipse/platformio
+eclipse/ruby_rails
+eclipse/selenium
+eclipse/ubuntu_android
+eclipse/ubuntu_go
+eclipse/ubuntu_gradle
+eclipse/ubuntu_jdk8
+eclipse/ubuntu_jre
+eclipse/ubuntu_python
+eclipse/ubuntu_wildfly8
+registry.centos.org/che-stacks/vertx
+
diff --git a/dockerfiles/cli/version/latest.ver b/dockerfiles/cli/version/latest.ver
index e0cb00460a..6fc6275499 100644
--- a/dockerfiles/cli/version/latest.ver
+++ b/dockerfiles/cli/version/latest.ver
@@ -1 +1 @@
-5.15.0
\ No newline at end of file
+5.16.0
\ No newline at end of file
diff --git a/dockerfiles/dev/Dockerfile b/dockerfiles/dev/Dockerfile
index 91a8fa36ce..818dfdbb81 100644
--- a/dockerfiles/dev/Dockerfile
+++ b/dockerfiles/dev/Dockerfile
@@ -21,6 +21,7 @@
# -Dfindbugs.skip=true
# -Dgwt.compiler.localWorkers=2 -T 1C
# -Dskip-validate-sources
+# -Pnative
# clean install
#
# For Windows, replace $HOME with maven repo directory.
diff --git a/dockerfiles/init/manifests/che.env b/dockerfiles/init/manifests/che.env
index 514133395a..45d02468fb 100644
--- a/dockerfiles/init/manifests/che.env
+++ b/dockerfiles/init/manifests/che.env
@@ -126,6 +126,13 @@
# Defaults to the same value of CHE_WORKSPACE_JAVA_OPTIONS.
#CHE_WORKSPACE_MAVEN_OPTIONS=NULL
+# Workspace Idle timeout
+# The length of time after which workspaces will be automatically stopped, if no activity
+# has been detected on them. Currently, keyboard and mouse interactions in IDE, as well as HTTP
+# requests to ws-agent count as activity. Set "0" to disable automatic stop of inactive workspaces.
+# Default to the value of this property in che.properties (3600000)
+#CHE_WORKSPACE_AGENT_DEV_INACTIVE__STOP__TIMEOUT__MS=0
+
########################################################################################
##### #####
##### NETWORKING #####
diff --git a/dockerfiles/lib/dto-pom.xml b/dockerfiles/lib/dto-pom.xml
index d2e4670614..bf97fae321 100644
--- a/dockerfiles/lib/dto-pom.xml
+++ b/dockerfiles/lib/dto-pom.xml
@@ -17,13 +17,13 @@
maven-depmgt-pomorg.eclipse.che.depmgt
- 5.16.0
+ 5.17.0-SNAPSHOTdto-typescriptpomChe TypeScript DTO
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOT
diff --git a/ide/che-core-dyna-provider-generator-maven-plugin/pom.xml b/ide/che-core-dyna-provider-generator-maven-plugin/pom.xml
index c4549c7d0f..96e14dc876 100644
--- a/ide/che-core-dyna-provider-generator-maven-plugin/pom.xml
+++ b/ide/che-core-dyna-provider-generator-maven-plugin/pom.xml
@@ -16,7 +16,7 @@
che-core-ide-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTche-core-dyna-provider-generator-maven-pluginmaven-plugin
diff --git a/ide/che-core-ide-api/pom.xml b/ide/che-core-ide-api/pom.xml
index 8f2fd41667..b132b247f7 100644
--- a/ide/che-core-ide-api/pom.xml
+++ b/ide/che-core-ide-api/pom.xml
@@ -16,7 +16,7 @@
che-core-ide-parentorg.eclipse.che.core
- 5.16.0-SNAPSHOT
+ 5.17.0-SNAPSHOTorg.eclipse.che.coreche-core-ide-api
diff --git a/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/project/MutableProjectConfig.java b/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/project/MutableProjectConfig.java
index a07af58c1f..6bacfcd173 100644
--- a/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/project/MutableProjectConfig.java
+++ b/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/project/MutableProjectConfig.java
@@ -138,14 +138,14 @@ public class MutableProjectConfig implements ProjectConfig {
public void setOptions(Map options) {
this.options = options;
}
-
+
public List getCommands() {
if (commands == null) {
commands = newArrayList();
}
return commands;
}
-
+
public void setCommands(List commands) {
this.commands = commands;
}
diff --git a/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/statepersistance/StateComponent.java b/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/statepersistance/StateComponent.java
index d4f457246d..7a92fc32d8 100644
--- a/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/statepersistance/StateComponent.java
+++ b/ide/che-core-ide-api/src/main/java/org/eclipse/che/ide/api/statepersistance/StateComponent.java
@@ -12,6 +12,8 @@ package org.eclipse.che.ide.api.statepersistance;
import elemental.json.JsonObject;
+import org.eclipse.che.api.promises.client.Promise;
+
import javax.validation.constraints.NotNull;
/**
@@ -20,14 +22,48 @@ import javax.validation.constraints.NotNull;
* a multibinder in order to be picked-up on IDE start-up:
*
diff --git a/agents/ls-csharp/src/main/resources/org.eclipse.che.ls.csharp.script.sh b/agents/ls-csharp/src/main/resources/org.eclipse.che.ls.csharp.script.sh
index 65b957fec6..087d8b6e27 100644
--- a/agents/ls-csharp/src/main/resources/org.eclipse.che.ls.csharp.script.sh
+++ b/agents/ls-csharp/src/main/resources/org.eclipse.che.ls.csharp.script.sh
@@ -61,8 +61,8 @@ if echo ${LINUX_TYPE} | grep -qi "rhel"; then
command -v dotnet >/dev/null 2>&1 || {
${SUDO} subscription-manager repos --enable=rhel-7-server-dotnet-rpms;
- ${SUDO} yum install scl-utils rh-dotnetcore10;
- ${SUDO} scl enable rh-dotnetcore10 bash;
+ ${SUDO} yum install scl-utils rh-dotnetcore20;
+ ${SUDO} scl enable rh-dotnetcore20 bash;
}
command -v nodejs >/dev/null 2>&1 || {
@@ -79,8 +79,8 @@ elif echo ${LINUX_TYPE} | grep -qi "Red Hat"; then
command -v dotnet >/dev/null 2>&1 || {
${SUDO} subscription-manager repos --enable=rhel-7-server-dotnet-rpms;
- ${SUDO} yum install scl-utils rh-dotnetcore10;
- ${SUDO} scl enable rh-dotnetcore10 bash;
+ ${SUDO} yum install scl-utils rh-dotnetcore20;
+ ${SUDO} scl enable rh-dotnetcore20 bash;
}
command -v nodejs >/dev/null 2>&1 || {
@@ -91,7 +91,7 @@ elif echo ${LINUX_TYPE} | grep -qi "Red Hat"; then
# Ubuntu 14.04 16.04 / Linux Mint 17
####################################
elif echo ${LINUX_TYPE} | grep -qi "ubuntu"; then
test "${PACKAGES}" = "" || {
@@ -99,22 +99,28 @@ elif echo ${LINUX_TYPE} | grep -qi "ubuntu"; then
${SUDO} apt-get -y install ${PACKAGES};
}
+ let RELEASE_NAME="trusty"
+ {
+ if echo ${LINUX_VERSION} | grep -qi "14.04"; then
+ RELEASE_NAME="trusty"
+ fi
+ if echo ${LINUX_VERSION} | grep -qi "16.04"; then
+ RELEASE_NAME="xenial"
+ fi
+ if echo ${LINUX_VERSION} | grep -qi "16.10"; then
+ RELEASE_NAME="yakkety"
+ fi
+ };
+
command -v dotnet >/dev/null 2>&1 || {
${SUDO} apt-get update;
${SUDO} apt-get -y install apt-transport-https;
- {
- if echo ${LINUX_VERSION} | grep -qi "16.04"; then
- ${SUDO} sh -c 'echo "deb [arch=amd64] https://apt-mo.trafficmanager.net/repos/dotnet-release/ xenial main" > /etc/apt/sources.list.d/dotnetdev.list'
- ${SUDO} apt-key adv --keyserver apt-mo.trafficmanager.net --recv-keys 417A0893
- else
- ${SUDO} sh -c 'echo "deb [arch=amd64] https://apt-mo.trafficmanager.net/repos/dotnet-release/ trusty main" > /etc/apt/sources.list.d/dotnetdev.list'
- ${SUDO} apt-key adv --keyserver apt-mo.trafficmanager.net --recv-keys 417A0893
- fi
- };
+ ${SUDO} sh -c 'echo "deb [arch=amd64] http://apt-mo.trafficmanager.net/repos/dotnet-release/ '${RELEASE_NAME}' main" > /etc/apt/sources.list.d/dotnetdev.list'
+ ${SUDO} apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys 417A0893
${SUDO} apt-get update
- ${SUDO} apt-get -y install dotnet-dev-1.0.0-preview2-003121
+ ${SUDO} apt-get -y install dotnet-sdk-2.0.0-preview2-006497
}
command -v nodejs >/dev/null 2>&1 || {
@@ -136,7 +142,7 @@ elif echo ${LINUX_TYPE} | grep -qi "debian"; then
}
command -v dotnet >/dev/null 2>&1 || {
- curl -L -o dotnet.tar.gz https://go.microsoft.com/fwlink/?LinkID=809130;
+ curl -L -o dotnet.tar.gz https://aka.ms/dotnet-sdk-2.0.0-preview2-linux-x64-bin;
${SUDO} apt-get update;
${SUDO} apt-get -y install libunwind8 gettext;
${SUDO} mkdir -p /opt/dotnet;
@@ -154,7 +160,7 @@ elif echo ${LINUX_TYPE} | grep -qi "debian"; then
${SUDO} apt-get install -y nodejs;
}
-# Fedora 23
+# Fedora 24, 25, 26
###########
elif echo ${LINUX_TYPE} | grep -qi "fedora"; then
PACKAGES=${PACKAGES}" procps-ng"
@@ -163,7 +169,7 @@ elif echo ${LINUX_TYPE} | grep -qi "fedora"; then
}
command -v dotnet >/dev/null 2>&1 || {
- curl -L -o dotnet.tar.gz https://go.microsoft.com/fwlink/?LinkID=816869;
+ curl -L -o dotnet.tar.gz https://aka.ms/dotnet-sdk-2.0.0-preview2-linux-x64-bin;
${SUDO} dnf -y install libunwind libicu;
${SUDO} mkdir -p /opt/dotnet;
${SUDO} tar zxf dotnet.tar.gz -C /opt/dotnet;
@@ -177,8 +183,7 @@ elif echo ${LINUX_TYPE} | grep -qi "fedora"; then
}
-
-# CentOS 7.1 & Oracle Linux 7.1
+# CentOS 7.1 (64 bit) & Oracle Linux 7.1 (64 bit)
###############################
elif echo ${LINUX_TYPE} | grep -qi "centos"; then
test "${PACKAGES}" = "" || {
@@ -186,7 +191,7 @@ elif echo ${LINUX_TYPE} | grep -qi "centos"; then
}
command -v dotnet >/dev/null 2>&1 || {
- curl -L -o dotnet.tar.gz https://go.microsoft.com/fwlink/?LinkID=809131;
+ curl -L -o dotnet.tar.gz https://aka.ms/dotnet-sdk-2.0.0-preview2-linux-x64-bin;
${SUDO} yum -y install libunwind libicu;
${SUDO} mkdir -p /opt/dotnet;
${SUDO} tar zxf dotnet.tar.gz -C /opt/dotnet;
@@ -200,7 +205,7 @@ elif echo ${LINUX_TYPE} | grep -qi "centos"; then
}
-# openSUSE 13.2
+# SUSE Linux Enterprise Server (64 bit), openSUSE (64 bit)
###############
elif echo ${LINUX_TYPE} | grep -qi "opensuse"; then
test "${PACKAGES}" = "" || {
@@ -208,7 +213,7 @@ elif echo ${LINUX_TYPE} | grep -qi "opensuse"; then
}
command -v dotnet >/dev/null 2>&1 || {
- curl -L -o dotnet.tar.gz https://go.microsoft.com/fwlink/?LinkID=816867;
+ curl -L -o dotnet.tar.gz https://aka.ms/dotnet-sdk-2.0.0-preview2-linux-x64-bin
${SUDO} zypper install -y libunwind libicu;
${SUDO} mkdir -p /opt/dotnet;
${SUDO} tar zxf dotnet.tar.gz -C /opt/dotnet;
@@ -91,7 +91,7 @@ elif echo ${LINUX_TYPE} | grep -qi "Red Hat"; then
command -v nodejs >/dev/null 2>&1 || {
-# Ubuntu 14.04 16.04 / Linux Mint 17
+# Install for Ubuntu 14.04, 16.04, 16.10 & Linux Mint 17, 18 (64 bit)
####################################
elif echo ${LINUX_TYPE} | grep -qi "ubuntu"; then
diff --git a/dashboard/src/app/workspaces/create-workspace/create-workspace.service.ts b/dashboard/src/app/workspaces/create-workspace/create-workspace.service.ts
index 513c95f5a2..e2f67863ef 100644
--- a/dashboard/src/app/workspaces/create-workspace/create-workspace.service.ts
+++ b/dashboard/src/app/workspaces/create-workspace/create-workspace.service.ts
@@ -163,7 +163,7 @@ export class CreateWorkspaceSvc {
createWorkspace(workspaceConfig: che.IWorkspaceConfig, attributes?: any): ng.IPromise {
const namespaceId = this.namespaceSelectorSvc.getNamespaceId(),
projectTemplates = this.projectSourceSelectorService.getProjectTemplates();
-
+ workspaceConfig.projects = projectTemplates;
return this.checkEditingProgress().then(() => {
return this.cheWorkspace.createWorkspaceFromConfig(namespaceId, workspaceConfig, attributes).then((workspace: che.IWorkspace) => {
@@ -177,13 +177,9 @@ export class CreateWorkspaceSvc {
}).then(() => {
return this.cheWorkspace.fetchWorkspaceDetails(workspace.id);
}).then(() => {
- return this.createProjects(workspace.id, projectTemplates);
- }).then(() => {
- this.getIDE().ProjectExplorer.refresh();
- return this.importProjects(workspace.id, projectTemplates);
+ return this.addProjectCommands(workspace.id, projectTemplates);
}).then(() => {
let IDE = this.getIDE();
- IDE.ProjectExplorer.refresh();
IDE.CommandManager.refresh();
});
}, (error: any) => {
@@ -242,20 +238,18 @@ export class CreateWorkspaceSvc {
}
/**
* Imports bunch of projects in row.
* Returns resolved promise if all project are imported properly, otherwise returns rejected promise with list of names of failed projects.
*
* @param {string} workspaceId the workspace ID
- * @param {Array} projectTemplates the list of project templates to import
+ * @param {Array} projectTemplates the list of project templates
* @return {IPromise}
*/
- importProjects(workspaceId: string, projectTemplates: Array): ng.IPromise {
+ addProjectCommands(workspaceId: string, projectTemplates: Array): ng.IPromise {
const defer = this.$q.defer();
defer.resolve();
let accumulatorPromise = defer.promise;
- const projectTypeResolverService = this.cheWorkspace.getWorkspaceAgent(workspaceId).getProjectTypeResolver();
-
const failedProjects = [];
accumulatorPromise = projectTemplates.reduce((_accumulatorPromise: ng.IPromise, project: che.IProjectTemplate) => {
@@ -263,8 +257,6 @@ export class CreateWorkspaceSvc {
return this.addCommands(workspaceId, project.name, project.commands).catch(() => {
// adding commands errors, ignore them here
return this.$q.when();
- }).then(() => {
- return projectTypeResolverService.resolveProjectType(project as any);
}).catch((error: any) => {
failedProjects.push(project.name);
if (error && error.message) {
@@ -242,20 +238,18 @@ export class CreateWorkspaceSvc {
}
/**
- * Imports bunch of projects in row.
- * Returns resolved promise if all project are imported properly, otherwise returns rejected promise with list of names of failed projects.
+ * Adds commands from the bunch of projects in row.
+ * Returns resolved promise if all commands are aded properly, otherwise returns rejected promise with list of names of failed projects.
*
* @param {string} workspaceId the workspace ID